==> test-contract-2.0.0-beta.0.tgz: package/lib/setup/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";

var _require = require('chai'),
    expect = _require.expect;

var _require2 = require('msw/node'),
    setupServer = _require2.setupServer;

var _require3 = require('@pactflow/pact-msw-adapter'),
    setupPactMswAdapter = _require3.setupPactMswAdapter;

var _require4 = require('@s-ui/js/lib/string'),
    toQueryString = _require4.toQueryString;

var _require5 = require('./utils.js'),
    writerFactory = _require5.writerFactory,
    mapProviders = _require5.mapProviders,
    getContractTests = _require5.getContractTests;

module.exports = function (_ref) {
  var apiUrl = _ref.apiUrl,
      consumer = _ref.consumer,
      providers = _ref.providers,
      fetcher = _ref.fetcher,
      defaultOptions = _ref.defaultOptions;
  var server = setupServer();
  var pactMswAdapter = setupPactMswAdapter({
    server: server,
    options: {
      consumer: consumer,
      providers: mapProviders(providers),
      pactOutDir: './contract/_documents',
      excludeHeaders: ['x-powered-by']
    }
  });
  var tests = getContractTests({
    apiUrl: apiUrl,
    providers: providers
  });
  describe('Consumer test contracts', function () {
    before( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              server.listen();

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    beforeEach( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              pactMswAdapter.newTest();

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    afterEach( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              pactMswAdapter.verifyTest();
              server.resetHandlers();

            case 2:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
    after( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
      var writer;
      return _regeneratorRuntime.wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              writer = writerFactory(providers);
              _context4.next = 3;
              return pactMswAdapter.writeToFile(writer);

            case 3:
              pactMswAdapter.clear();
              server.close();

            case 5:
            case "end":
              return _context4.stop();
          }
        }
      }, _callee4);
    })));
    tests.forEach(function (_ref6) {
      var description = _ref6.description,
          endpoint = _ref6.endpoint,
          query = _ref6.query,
          body = _ref6.body,
          _ref6$method = _ref6.method,
          method = _ref6$method === void 0 ? 'get' : _ref6$method,
          handler = _ref6.handler,
          _ref6$options = _ref6.options,
          options = _ref6$options === void 0 ? defaultOptions : _ref6$options,
          response = _ref6.response;
      it("makes " + description.toLowerCase(), /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
        var url, _ref8, data;

        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                server.use(handler);
                url = "" + apiUrl + endpoint;
                if (query) url = url + "?" + toQueryString(query);

                if (!(method === 'post')) {
                  _context5.next = 9;
                  break;
                }

                _context5.next = 6;
                return fetcher[method](url, body, options);

              case 6:
                _context5.t0 = _context5.sent;
                _context5.next = 12;
                break;

              case 9:
                _context5.next = 11;
                return fetcher[method](url, options);

              case 11:
                _context5.t0 = _context5.sent;

              case 12:
                _ref8 = _context5.t0;
                data = _ref8.data;
                if (data) expect(data).to.deep.equal(response);

              case 15:
              case "end":
                return _context5.stop();
            }
          }
        }, _callee5);
      })));
    });
  });
};

==> test-contract-2.9.0-beta.0.tgz: package/lib/setup/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { expect } from 'chai';
import { setupServer } from 'msw/node';
import { setupPactMswAdapter } from '@pactflow/pact-msw-adapter';
import { getContractTests, mapProviders, toQueryString, writerFactory } from './utils.js';
var setupContractTests = function setupContractTests(_ref) {
  var defaultApiUrl = _ref.apiUrl,
    consumer = _ref.consumer,
    providers = _ref.providers,
    fetcher = _ref.fetcher,
    defaultOptions = _ref.defaultOptions,
    _ref$excludeHeaders = _ref.excludeHeaders,
    excludeHeaders = _ref$excludeHeaders === void 0 ? ['x-powered-by', 'accept', 'user-agent', 'cookie'] : _ref$excludeHeaders,
    _ref$contractsDir = _ref.contractsDir,
    contractsDir = _ref$contractsDir === void 0 ? './contract/documents' : _ref$contractsDir;
  var server = setupServer();
  var pactMswAdapter = setupPactMswAdapter({
    server: server,
    options: {
      consumer: consumer,
      providers: mapProviders(providers),
      pactOutDir: contractsDir,
      excludeHeaders: excludeHeaders
    }
  });
  var tests = getContractTests({
    apiUrl: defaultApiUrl,
    providers: providers
  });
  describe('Consumer test contracts', function () {
    before( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              server.listen({
                onUnhandledRequest: 'warn'
              });
            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    beforeEach( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              pactMswAdapter.newTest();
            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    afterEach( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              pactMswAdapter.verifyTest();
              server.resetHandlers();
            case 2:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
    after( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
      var writer;
      return _regeneratorRuntime.wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              writer = writerFactory(providers);
              _context4.next = 3;
              return pactMswAdapter.writeToFile(writer);
            case 3:
              pactMswAdapter.clear();
              server.close();
            case 5:
            case "end":
              return _context4.stop();
          }
        }
      }, _callee4);
    })));
    tests.forEach(function (_ref6) {
      var description = _ref6.description,
        endpointApiUrl = _ref6.apiUrl,
        endpoint = _ref6.endpoint,
        query = _ref6.query,
        body = _ref6.body,
        _ref6$method = _ref6.method,
        method = _ref6$method === void 0 ? 'get' : _ref6$method,
        handler = _ref6.handler,
        _ref6$options = _ref6.options,
        options = _ref6$options === void 0 ? defaultOptions : _ref6$options,
        response = _ref6.response;
      it("makes " + description.toLowerCase(), /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
        var apiUrl, url, _ref8, data;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                server.use(handler);
                apiUrl = endpointApiUrl || defaultApiUrl;
                url = "" + apiUrl + endpoint;
                if (query) url = url + "?" + toQueryString(query);
                if (!body) {
                  _context5.next = 10;
                  break;
                }
                _context5.next = 7;
                return fetcher[method](url, body, options);
              case 7:
                _context5.t0 = _context5.sent;
                _context5.next = 13;
                break;
              case 10:
                _context5.next = 12;
                return fetcher[method](url, options);
              case 12:
                _context5.t0 = _context5.sent;
              case 13:
                _ref8 = _context5.t0;
                data = _ref8.data;
                if (data) expect(data).to.deep.equal(response);
              case 16:
              case "end":
                return _context5.stop();
            }
          }
        }, _callee5);
      })));
    });
  });
};
export default setupContractTests;
